@@ -1,9 +1,11 @@
 `print.summary.mefa` <-
-function(x, nlist=10, ...)
+function(x, nlist, ...)
 {
+    if (missing(nlist))
+        nlist <- attr(x, "nlist")
     mstat <- cbind(summary(x[[1]]), summary(x[[2]]),
         summary(x[[3]]), summary(x[[4]]))
-    colnames(mstat) <- c("S richnness", "N individuals", "Occupancy", "Abundance")
+    colnames(mstat) <- c("s.rich", "s.abu", "t.occ", "t.abu")
     Summary <- c(x$ntot, round(x$mfill*100), x$nsamp, x$ntaxa, x$nsegm)
     names(Summary) <- c("Total sum", "Matrix fill (%)", "Number of samples", "Number of taxa", "Number of segments")
 
@@ -14,8 +16,9 @@ function(x, nlist=10, ...)
     seglist <- x$segment
     if (length(seglist) > nlist)
         seglist <- c(seglist[1:nlist], "[...]")
+    neststr <- if (x$nested) " (nested)" else " (non-nested)"
     if (length(seglist) == 1)
-        cat("\nSegment:\n", sep="") else cat("\nSegments:\n", sep="")
+        cat("\nSegment", neststr, ":\n", sep="") else cat("\nSegments", neststr, ":\n", sep="")
     cat(seglist, sep=", ")
     cat("\n\n")
     print(mstat, ...)
